| Title: | A Neural Networks Framework |
|---|---|
| Description: | This package provides a layer oriented way of creating neural networks, the framework is intended to give the user total control of the internals of a net without much effort. Use classes like PerceptronLayer to create a layer of percetron neurons, and specify how many you want. The package does all the tricky stuff internally leaving you focused in what you want. I wrote this package during a neural networks course to help me with the problem set. |
| Authors: | Brian Lee Mayer |
| Maintainer: | Brian <[email protected]> |
| License: | GPL-3 + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-02 10:46:02 UTC |
| Source: | https://github.com/blmayer/deep |
The deep package provides classes for layers, types of neurons and the neural network as a whole.
The McCullochPitts neuron class, that implements the logic of the McCullochPitts neuron model.
inputs |
The actual data to be fed to the nuron, this input's dimentions vary with the chosen weights dimentions. |
ins |
The list of vectors of inputs to the first layer in the network |
outs |
The list of vectors of outputs of the last layer in the network |
epochs |
How many rounds of training to run |
tax |
This is the learning rate, aka eta |
maxErr |
A contition to early stop the training process |
The computed value using the McCullochPitts model.
Vector of computed values of the same size of the last layer
wsThe matrix of weights that multiply the input vector, it can be a vector, a matrix or an array.
biasThe bias value.
The McCullochPittsLayer class, that implements a layer of McCullochPitts neurons.
input |
The actual data to be fed to the layer, this input's
dimentions vary with the chosen |
ins |
The list of vectors of inputs to the first layer in the network |
outs |
The list of vectors of outputs of the last layer in the network |
epochs |
How many rounds of training to run |
tax |
This is the learning rate, aka eta |
maxErr |
A contition to early stop the training process |
The computed value using the McCullochPittsLayer model.
Vector of computed values of the same size of the last layer
nThe number of neurons to create in the layer
dimsA vector of dimensions of the inputs to the layer
neuronsA list with the internal neurons
The main NeuralNetwork class, that holds the layers.
etaThe learning tax, representes the size of the weight adjustment between each epoch of training.
layersThis field is a list of the layers of the network, you can use subsetting to inspect them.
The Perceptron neuron class, that implements the logic of the perceptron model.
inputs |
The actual data to be fed to the neuron, this input's dimentions vary with the chosen weights dimentions. |
ins |
The list of vectors of inputs to the first layer in the network |
outs |
The list of vectors of outputs of the last layer in the network |
epochs |
How many rounds of training to run |
tax |
This is the learning rate, aka eta |
maxErr |
A contition to early stop the training process |
The computed value using the Perceptron model.
Vector of computed values of the same size of the last layer
wsThe matrix of weights that multiply the input vector, it can be a vector, a matrix or an array.
biasThe bias value.
The PerceptronLayer class, that implements a layer of Perceptron neurons.
input |
The actual data to be fed to the layer, this input's
dimentions vary with the chosen |
ins |
The list of vectors of inputs to the first layer in the network |
outs |
The list of vectors of outputs of the last layer in the network |
epochs |
How many rounds of training to run |
tax |
This is the learning rate, aka eta |
maxErr |
A contition to early stop the training process |
The computed value using the Perceptron model.
Vector of computed values of the same size of the last layer
nThe number of neurons to create in the layer
dimsA vector of dimensions of the inputs to the layer
neuronsA list with the internal neurons